@@ -7,6 +7,12 @@ import rsa
 
 
 def verify_response(public_key: str, response: dict):
+    """
+    Verifies an API response using the signature in the response and a public key
+
+    Raises:
+        ValueError: When the signature does not match or an invalid response is supplied
+    """
     if not response or not isinstance(response, dict):
         raise ValueError('Response is not a valid dictionary')
     signature = response.pop('signature', None)
@@ -23,6 +29,12 @@ def verify_response(public_key: str, response: dict):
 
 @lru_cache()
 def get_public_key():
+    """
+    Retrieves the public key of this client
+
+    Returns:
+        str: The public key contents
+    """
     script_dir = os.path.dirname(__file__)
     with open(script_dir + '/public.pem', 'r') as f:
         return f.read()
