@@ -11,7 +11,6 @@ class Dataset(AbstractApiClass):
         Args:
             client (ApiClient): An authenticated API Client instance
             datasetId (str): The unique identifier of the dataset.
-            name (str): The user-friendly name of the dataset.
             sourceType (str): The source of the Dataset. EXTERNAL_SERVICE, UPLOAD, or STREAMING.
             dataSource (str): Location of data. It may be a URI such as an s3 bucket or the database table.
             createdAt (str): The timestamp at which this dataset was created.
@@ -25,15 +24,15 @@ class Dataset(AbstractApiClass):
             applicationConnectorId (str): The Application Connector used.
             applicationConnectorConfig (dict): The application connector query used to retrieve data.
             incremental (bool): If dataset is an incremental dataset.
+            name (str): 
             latestDatasetVersion (DatasetVersion): The latest version of this dataset.
             schema (DatasetColumn): List of resolved columns.
             refreshSchedules (RefreshSchedule): List of schedules that determines when the next version of the dataset will be created.
     """
 
-    def __init__(self, client, datasetId=None, name=None, sourceType=None, dataSource=None, createdAt=None, ignoreBefore=None, ephemeral=None, lookbackDays=None, databaseConnectorId=None, databaseConnectorConfig=None, connectorType=None, featureGroupTableName=None, applicationConnectorId=None, applicationConnectorConfig=None, incremental=None, schema={}, refreshSchedules={}, latestDatasetVersion={}):
+    def __init__(self, client, datasetId=None, sourceType=None, dataSource=None, createdAt=None, ignoreBefore=None, ephemeral=None, lookbackDays=None, databaseConnectorId=None, databaseConnectorConfig=None, connectorType=None, featureGroupTableName=None, applicationConnectorId=None, applicationConnectorConfig=None, incremental=None, name=None, schema={}, refreshSchedules={}, latestDatasetVersion={}):
         super().__init__(client, datasetId)
         self.dataset_id = datasetId
-        self.name = name
         self.source_type = sourceType
         self.data_source = dataSource
         self.created_at = createdAt
@@ -47,6 +46,7 @@ class Dataset(AbstractApiClass):
         self.application_connector_id = applicationConnectorId
         self.application_connector_config = applicationConnectorConfig
         self.incremental = incremental
+        self.name = name
         self.schema = client._build_class(DatasetColumn, schema)
         self.refresh_schedules = client._build_class(
             RefreshSchedule, refreshSchedules)
@@ -54,7 +54,7 @@ class Dataset(AbstractApiClass):
             DatasetVersion, latestDatasetVersion)
 
     def __repr__(self):
-        return f"Dataset(dataset_id={repr(self.dataset_id)},\n  name={repr(self.name)},\n  source_type={repr(self.source_type)},\n  data_source={repr(self.data_source)},\n  created_at={repr(self.created_at)},\n  ignore_before={repr(self.ignore_before)},\n  ephemeral={repr(self.ephemeral)},\n  lookback_days={repr(self.lookback_days)},\n  database_connector_id={repr(self.database_connector_id)},\n  database_connector_config={repr(self.database_connector_config)},\n  connector_type={repr(self.connector_type)},\n  feature_group_table_name={repr(self.feature_group_table_name)},\n  application_connector_id={repr(self.application_connector_id)},\n  application_connector_config={repr(self.application_connector_config)},\n  incremental={repr(self.incremental)},\n  schema={repr(self.schema)},\n  refresh_schedules={repr(self.refresh_schedules)},\n  latest_dataset_version={repr(self.latest_dataset_version)})"
+        return f"Dataset(dataset_id={repr(self.dataset_id)},\n  source_type={repr(self.source_type)},\n  data_source={repr(self.data_source)},\n  created_at={repr(self.created_at)},\n  ignore_before={repr(self.ignore_before)},\n  ephemeral={repr(self.ephemeral)},\n  lookback_days={repr(self.lookback_days)},\n  database_connector_id={repr(self.database_connector_id)},\n  database_connector_config={repr(self.database_connector_config)},\n  connector_type={repr(self.connector_type)},\n  feature_group_table_name={repr(self.feature_group_table_name)},\n  application_connector_id={repr(self.application_connector_id)},\n  application_connector_config={repr(self.application_connector_config)},\n  incremental={repr(self.incremental)},\n  name={repr(self.name)},\n  schema={repr(self.schema)},\n  refresh_schedules={repr(self.refresh_schedules)},\n  latest_dataset_version={repr(self.latest_dataset_version)})"
 
     def to_dict(self):
         """
@@ -63,7 +63,7 @@ class Dataset(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'dataset_id': self.dataset_id, 'name': self.name, 'source_type': self.source_type, 'data_source': self.data_source, 'created_at': self.created_at, 'ignore_before': self.ignore_before, 'ephemeral': self.ephemeral, 'lookback_days': self.lookback_days, 'database_connector_id': self.database_connector_id, 'database_connector_config': self.database_connector_config, 'connector_type': self.connector_type, 'feature_group_table_name': self.feature_group_table_name, 'application_connector_id': self.application_connector_id, 'application_connector_config': self.application_connector_config, 'incremental': self.incremental, 'schema': self._get_attribute_as_dict(self.schema), 'refresh_schedules': self._get_attribute_as_dict(self.refresh_schedules), 'latest_dataset_version': self._get_attribute_as_dict(self.latest_dataset_version)}
+        return {'dataset_id': self.dataset_id, 'source_type': self.source_type, 'data_source': self.data_source, 'created_at': self.created_at, 'ignore_before': self.ignore_before, 'ephemeral': self.ephemeral, 'lookback_days': self.lookback_days, 'database_connector_id': self.database_connector_id, 'database_connector_config': self.database_connector_config, 'connector_type': self.connector_type, 'feature_group_table_name': self.feature_group_table_name, 'application_connector_id': self.application_connector_id, 'application_connector_config': self.application_connector_config, 'incremental': self.incremental, 'name': self.name, 'schema': self._get_attribute_as_dict(self.schema), 'refresh_schedules': self._get_attribute_as_dict(self.refresh_schedules), 'latest_dataset_version': self._get_attribute_as_dict(self.latest_dataset_version)}
 
     def create_version_from_file_connector(self, location: str = None, file_format: str = None, csv_delimiter: str = None):
         """
@@ -138,7 +138,7 @@ class Dataset(AbstractApiClass):
 
         Args:
             column (str): The name of the column.
-            data_type (str): The type of the data in the column.  INTEGER,  FLOAT,  STRING,  DATE,  DATETIME,  BOOLEAN,  LIST,  STRUCT Refer to the (guide on data types)[https://api.abacus.ai/app/help/class/DataType] for more information. Note: Some ColumnMappings will restrict the options or explicity set the DataType.
+            data_type (str): The type of the data in the column.  INTEGER,  FLOAT,  STRING,  DATE,  DATETIME,  BOOLEAN,  LIST,  STRUCT Refer to the (guide on data types)[https://api.abacus.ai/app/help/class/DataType] for more information. Note: Some ColumnMappings will restrict the options or explicitly set the DataType.
 
         Returns:
             Dataset: The dataset and schema after the data_type has been set
@@ -227,15 +227,6 @@ class Dataset(AbstractApiClass):
         """
         return self.client.remove_dataset_from_project(self.dataset_id, project_id)
 
-    def rename(self, name: str):
-        """
-        Rename a dataset.
-
-        Args:
-            name (str): The new name for the dataset.
-        """
-        return self.client.rename_dataset(self.dataset_id, name)
-
     def delete(self):
         """
         Deletes the specified dataset from the organization.
@@ -307,7 +298,7 @@ class Dataset(AbstractApiClass):
         Returns:
             RefreshPolicy: The refresh policy object.
         """
-        return self.client.create_refresh_policy(self.name, cron, 'DATASET', dataset_ids=[self.id])
+        return self.client.create_refresh_policy(self.feature_group_table_name, cron, 'DATASET', dataset_ids=[self.id])
 
     def list_refresh_policies(self):
         """
