@@ -22,9 +22,10 @@ class FeatureGroupExport(AbstractApiClass):
             exportCompletedAt (str): The timestamp at which the export completed
             additionalIdColumns (list of string): For database connectors which support it, additional ID columns to use as a complex key for upserting
             error (str): If status is FAILED, this field will be populated with an error.
+            databaseOutputError (bool): If true, there were errors reported by the database connector while writing
     """
 
-    def __init__(self, client, featureGroupExportId=None, featureGroupVersion=None, connectorType=None, outputLocation=None, fileFormat=None, databaseConnectorId=None, objectName=None, writeMode=None, databaseFeatureMapping=None, idColumn=None, status=None, createdAt=None, exportCompletedAt=None, additionalIdColumns=None, error=None):
+    def __init__(self, client, featureGroupExportId=None, featureGroupVersion=None, connectorType=None, outputLocation=None, fileFormat=None, databaseConnectorId=None, objectName=None, writeMode=None, databaseFeatureMapping=None, idColumn=None, status=None, createdAt=None, exportCompletedAt=None, additionalIdColumns=None, error=None, databaseOutputError=None):
         super().__init__(client, featureGroupExportId)
         self.feature_group_export_id = featureGroupExportId
         self.feature_group_version = featureGroupVersion
@@ -41,9 +42,10 @@ class FeatureGroupExport(AbstractApiClass):
         self.export_completed_at = exportCompletedAt
         self.additional_id_columns = additionalIdColumns
         self.error = error
+        self.database_output_error = databaseOutputError
 
     def __repr__(self):
-        return f"FeatureGroupExport(feature_group_export_id={repr(self.feature_group_export_id)},\n  feature_group_version={repr(self.feature_group_version)},\n  connector_type={repr(self.connector_type)},\n  output_location={repr(self.output_location)},\n  file_format={repr(self.file_format)},\n  database_connector_id={repr(self.database_connector_id)},\n  object_name={repr(self.object_name)},\n  write_mode={repr(self.write_mode)},\n  database_feature_mapping={repr(self.database_feature_mapping)},\n  id_column={repr(self.id_column)},\n  status={repr(self.status)},\n  created_at={repr(self.created_at)},\n  export_completed_at={repr(self.export_completed_at)},\n  additional_id_columns={repr(self.additional_id_columns)},\n  error={repr(self.error)})"
+        return f"FeatureGroupExport(feature_group_export_id={repr(self.feature_group_export_id)},\n  feature_group_version={repr(self.feature_group_version)},\n  connector_type={repr(self.connector_type)},\n  output_location={repr(self.output_location)},\n  file_format={repr(self.file_format)},\n  database_connector_id={repr(self.database_connector_id)},\n  object_name={repr(self.object_name)},\n  write_mode={repr(self.write_mode)},\n  database_feature_mapping={repr(self.database_feature_mapping)},\n  id_column={repr(self.id_column)},\n  status={repr(self.status)},\n  created_at={repr(self.created_at)},\n  export_completed_at={repr(self.export_completed_at)},\n  additional_id_columns={repr(self.additional_id_columns)},\n  error={repr(self.error)},\n  database_output_error={repr(self.database_output_error)})"
 
     def to_dict(self):
         """
@@ -52,7 +54,7 @@ class FeatureGroupExport(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'feature_group_export_id': self.feature_group_export_id, 'feature_group_version': self.feature_group_version, 'connector_type': self.connector_type, 'output_location': self.output_location, 'file_format': self.file_format, 'database_connector_id': self.database_connector_id, 'object_name': self.object_name, 'write_mode': self.write_mode, 'database_feature_mapping': self.database_feature_mapping, 'id_column': self.id_column, 'status': self.status, 'created_at': self.created_at, 'export_completed_at': self.export_completed_at, 'additional_id_columns': self.additional_id_columns, 'error': self.error}
+        return {'feature_group_export_id': self.feature_group_export_id, 'feature_group_version': self.feature_group_version, 'connector_type': self.connector_type, 'output_location': self.output_location, 'file_format': self.file_format, 'database_connector_id': self.database_connector_id, 'object_name': self.object_name, 'write_mode': self.write_mode, 'database_feature_mapping': self.database_feature_mapping, 'id_column': self.id_column, 'status': self.status, 'created_at': self.created_at, 'export_completed_at': self.export_completed_at, 'additional_id_columns': self.additional_id_columns, 'error': self.error, 'database_output_error': self.database_output_error}
 
     def get_feature_group_version_export_download_url(self):
         """
@@ -88,6 +90,15 @@ class FeatureGroupExport(AbstractApiClass):
         """
         return self.client.describe_feature_group_export(self.feature_group_export_id)
 
+    def get_connector_errors(self):
+        """
+        Returns a stream containing the feature group export database connection write errors, if any writes failed to the database connector
+
+        Args:
+            feature_group_export_id (str): The ID of the feature group export to get the errors for
+        """
+        return self.client.get_feature_group_export_connector_errors(self.feature_group_export_id)
+
     def wait_for_results(self, timeout=3600):
         """
         A waiting call until feature group export is created.
