@@ -24,12 +24,13 @@ class FeatureGroupVersion(AbstractApiClass):
             deployable (bool): whether feature group is deployable or not.
             cpuSize (str): Cpu size specified for the python feature group.
             memory (int): Memory in GB specified for the python feature group.
+            useOriginalCsvNames (bool): If true, the feature group will use the original column names in the source dataset.
             features (Feature): List of features.
             pointInTimeGroups (PointInTimeGroup): List of Point In Time Groups
             codeSource (CodeSource): If a python feature group, information on the source code
     """
 
-    def __init__(self, client, featureGroupVersion=None, featureGroupId=None, sql=None, sourceTables=None, createdAt=None, status=None, error=None, deployable=None, cpuSize=None, memory=None, features={}, pointInTimeGroups={}, codeSource={}):
+    def __init__(self, client, featureGroupVersion=None, featureGroupId=None, sql=None, sourceTables=None, createdAt=None, status=None, error=None, deployable=None, cpuSize=None, memory=None, useOriginalCsvNames=None, features={}, pointInTimeGroups={}, codeSource={}):
         super().__init__(client, featureGroupVersion)
         self.feature_group_version = featureGroupVersion
         self.feature_group_id = featureGroupId
@@ -41,13 +42,14 @@ class FeatureGroupVersion(AbstractApiClass):
         self.deployable = deployable
         self.cpu_size = cpuSize
         self.memory = memory
+        self.use_original_csv_names = useOriginalCsvNames
         self.features = client._build_class(Feature, features)
         self.point_in_time_groups = client._build_class(
             PointInTimeGroup, pointInTimeGroups)
         self.code_source = client._build_class(CodeSource, codeSource)
 
     def __repr__(self):
-        return f"FeatureGroupVersion(feature_group_version={repr(self.feature_group_version)},\n  feature_group_id={repr(self.feature_group_id)},\n  sql={repr(self.sql)},\n  source_tables={repr(self.source_tables)},\n  created_at={repr(self.created_at)},\n  status={repr(self.status)},\n  error={repr(self.error)},\n  deployable={repr(self.deployable)},\n  cpu_size={repr(self.cpu_size)},\n  memory={repr(self.memory)},\n  features={repr(self.features)},\n  point_in_time_groups={repr(self.point_in_time_groups)},\n  code_source={repr(self.code_source)})"
+        return f"FeatureGroupVersion(feature_group_version={repr(self.feature_group_version)},\n  feature_group_id={repr(self.feature_group_id)},\n  sql={repr(self.sql)},\n  source_tables={repr(self.source_tables)},\n  created_at={repr(self.created_at)},\n  status={repr(self.status)},\n  error={repr(self.error)},\n  deployable={repr(self.deployable)},\n  cpu_size={repr(self.cpu_size)},\n  memory={repr(self.memory)},\n  use_original_csv_names={repr(self.use_original_csv_names)},\n  features={repr(self.features)},\n  point_in_time_groups={repr(self.point_in_time_groups)},\n  code_source={repr(self.code_source)})"
 
     def to_dict(self):
         """
@@ -56,7 +58,7 @@ class FeatureGroupVersion(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'feature_group_version': self.feature_group_version, 'feature_group_id': self.feature_group_id, 'sql': self.sql, 'source_tables': self.source_tables, 'created_at': self.created_at, 'status': self.status, 'error': self.error, 'deployable': self.deployable, 'cpu_size': self.cpu_size, 'memory': self.memory, 'features': self._get_attribute_as_dict(self.features), 'point_in_time_groups': self._get_attribute_as_dict(self.point_in_time_groups), 'code_source': self._get_attribute_as_dict(self.code_source)}
+        return {'feature_group_version': self.feature_group_version, 'feature_group_id': self.feature_group_id, 'sql': self.sql, 'source_tables': self.source_tables, 'created_at': self.created_at, 'status': self.status, 'error': self.error, 'deployable': self.deployable, 'cpu_size': self.cpu_size, 'memory': self.memory, 'use_original_csv_names': self.use_original_csv_names, 'features': self._get_attribute_as_dict(self.features), 'point_in_time_groups': self._get_attribute_as_dict(self.point_in_time_groups), 'code_source': self._get_attribute_as_dict(self.code_source)}
 
     def create_snapshot_feature_group(self, table_name: str):
         """
@@ -155,7 +157,7 @@ class FeatureGroupVersion(AbstractApiClass):
         Args:
             timeout (int, optional): The waiting time given to the call to finish, if it doesn't finish by the allocated time, the call is said to be timed out.
         """
-        return self.client._poll(self, {'PENDING'}, timeout=timeout)
+        return self.client._poll(self, {'PENDING', 'GENERATING'}, timeout=timeout)
 
     def wait_for_materialization(self, timeout=3600):
         """
